********************************************************************************
****** Spillovers in ICT Adoption from Formal to Informal Firms: ***************
****** Evidence from Zambia ****************************************************
****** Filip Jolevski, Gaurav Nayyar, Regina Pleninger, Shu Yu *****************
********************************************************************************

clear all
set more off
set scheme plotplain, perm
graph set window fontface Garamond

** Change Path here:
global path "C:\Temp\RR_ZMB_2024_109\Reproducibility Package\"

sysdir set PLUS "$path/ado/"

********************************************************************************
********************************************************************************
** Dataset Creation ************************************************************
********************************************************************************
********************************************************************************


********************************************************************************
** Cleaning Survey Datasets ****************************************************
********************************************************************************

** Large Formal Firms (WBES) ***************************************************

clear
use "$path\\Data\Zambia-2019-full data.dta"

	* Add variable with survey type
	generate type = "ES"
	label var type "Type of Survey"

	* Keep only necessary variables
	keep idstd a14y c22b type d2 l1 wweak stratificationregioncode strata
	
	
	* Rename to match variable names in informal/micro datasets
	rename c22b ZAMc1 // Website
	
	* Clean up digital variables
	foreach var in ZAMc1 {
	replace `var' = . if `var' < 0
	replace `var' = 0 if `var' == 2
	}

	svyset stratificationregioncode [pweight=wweak], strata(strata)
	svy: mean ZAMc1


	* Save ES Formal Dataset
	save "$path\\Data\Formal.dta", replace

	
** Micro Formal Firms (WBMES) **************************************************
clear
use "$path\\Data\ZambiaMicro-2019-full data-long form.dta"

	* Add variable with survey type
	generate type = "Micro"
	label var type "Type of Survey"

	* Append ES Formal Dataset and save formal Dataset
	append using "$path\\Data\Formal.dta"
	
	* Clean up digital variables
	foreach var in c42a c42b c42c k11a ZAMc1 {
	replace `var' = . if `var' < 0
	replace `var' = 0 if `var' == 2
	}

	save "$path\\Data\FormalMicro.dta", replace	



** Informal Businesses (WBISES) & Append ***************************************
clear
use "$path\\Data\ZambiaInformal and Micro-2019-full.dta"

	* Add variable with survey type
	generate type = "Inf"
	label var type "Type of Survey"
	
	* Keep only firms with long form interviews
	keep if status==1

	* Append Dataset and save 
	append using "$path\\Data\FormalMicro.dta"

	* Clean up digital variables
	foreach var in c42a c42b c42c k11a ZAMc1 {
	replace `var' = . if `var' < 0
	replace `var' = 0 if `var' == 2
	}

	* Format Variables
	format c42a c42b c42c k11a ZAMc1 %9.4g 

	save "$path\\Data\AllSurveys.dta", replace	

erase "$path\\Data\FormalMicro.dta"


********************************************************************************
** Merge All Datasets **********************************************************
********************************************************************************    

// Note that the distance and productivity datasets are provided by the authors because the source data is restricted.

clear
use "$path\\Data\AllSurveys.dta"
order idstd type

local dtafiles "Dist_ClosestES" "Dist_ClosestFormal" "Dist_ClosestFormal_ALL_weak" "SquareDensity_count" "Dist_ClosestFormal_Web" 
foreach dtafile in "`dtafiles'" {
	display "`dtafile'"
	merge 1:1 idstd using "$path\\Data\\`dtafile'.dta"
	drop _merge	
}

order idstd type dist* closest*
sort idstd

** Rename distance measures

rename dist_ES dist_Inf_ES
rename dist_formal dist_Inf_formal 
rename dist_formal_all_weak dist_Inf_formal_all_weak

** Add altitude data
merge 1:1 idstd using "$path\\Data\Altitude.dta", force
drop _merge

** Add night lights data
merge 1:1 idstd using "$path\\Data\NTL.dta"
drop _merge

* Add productivity of closest firm
merge m:1 idstd_closest_base using "$path\\Data\Productivity.dta"
drop _merge

* Add Square Density
merge m:1 id_square using "$path\\Data\squareid.dta"
drop _merge

ren id_square id_square_P
destring squ_id0, replace
ren squ_id0 id_square

merge m:1 id_square using "$path\\Data\SquareDensity.dta"



********************************************************************************
** Further Cleaning ************************************************************
********************************************************************************
 
** Clean variables
local list sc2 l1a l1b l3 b3 b9 b11 l7a l7b l7c l7d b10 b8a a4m a4r a4s MICd2 MICn3 d4 d6 n7a n7a1 n7a2 c31a c32 c33 c34h c34min c38 c39 c40 c41h c41min ZAMd1 ZAMd2 d14 d10a r9 ir1a ir1b ir1e b17 b18 d2 l1
foreach var in `list'{
	replace `var'=. if `var'==-9
}


** Years in operation
gen yr_op= a14y- b3
label var yr_op "Years in operation"


** Sales
replace MICn3=0 if MICn3==-7 // MICn3=-7 means that firms were not in operation two years ago


** Owner's education and experience
gen owner_a_high=0 if b11!=.
replace owner_a_high=1 if b11>4&b11!=.
label var owner_a_high "A dummy that equals to 1 if the owner's education is above upper secondary school"

generate experience_specific = 0 
replace experience_specific=1 if b8a==1 | b8a==4
label variable experience_specific "Prior Experience in same type of business"


** Sector variable
gen manuf=0 if type!="ES"
replace manuf=1 if a4m!=.&type!="ES"
label var manuf "A dummy that equals to 1 if the firm is in the manufacturing sector"

gen retail=0 if type!="ES"
replace retail=1 if a4r!=.&type!="ES"
label var retail "A dummy that equals to 1 if the firm is in the retail sector"

gen service=0 if type!="ES"
replace service=1 if a4s!=.&type!="ES"
label var service "A dummy that equals to 1 if the firm is in the service sector"

generate sector2 = 0 if retail==1 | service==1
replace sector2 = 1 if manuf==1

label var sector2 "Sector dummy (1=manuf, 0=services (inc. retail))"


** Numver of Years This Business Has Been Working With The Primary Supplier
replace d14=. if d14==240
replace d14=a14y-d14 if d14>2000&d14!=.


** Visited competitors dummy
foreach i in ir1a {
	gen d_`i'=0 if `i'!=.
	replace d_`i'=1 if `i'==1
}


** Keep only relevant variables
keep c42a c42b c42c ZAMc1 k11a k10 gps_square__Altitude ln_d2_l1 rastervalu d_ir1a MICd2 sc2 d2 l1 MICn3 c3 c31a r1 r7 city owner_a_high yr_op experience_specific sector2 dist_Inf_formal dist_Inf_ES dist_Inf_formal_all_weak dist_Inf_formal_web density_sq_infcount_weak  b9 rastervalu idstd idstd_closest_base type status city wweak c1a b3 d_ir1a ZAMd1 ZAMd2 sc3a sc3b sc3c strata id_square type stratificationregioncode  density_sq_fcount_weak


save "$path\\Data\Data.dta", replace


********************************************************************************
********************************************************************************
** Analysis ********************************************************************
********************************************************************************
********************************************************************************

** Read in data
use "$path\\Data\Data.dta", clear

** Relabel variables
label variable c42a "PC"
label variable c42b "Tablet"
label variable c42c "Phone"
label variable ZAMc1 "Website"
label variable k11a "MM"
label variable k10 "BBA"
label variable gps_square__Altitude "Elevation"
label variable rastervalu "Nighttime Lights Emission"
label variable d_ir1a "Visited Competitors"

** Create additional variables
gen sales=MICd2
replace sales=MICn3 if MICd2==.& MICn3!=.
gen lab_prod3=sales/sc2
gen lnlab2=log(lab_prod3+1)
label var lnlab2 "Informal Labor Productivity (log)"

** Cleaning variables
replace c31a=0 if c31a==2

** Labeling variables
label variable city "City"
label variable owner_a_high "Owner's Education (1=above secondary)"
label variable r1 "Registration considered (last 3 years)"
label variable yr_op "Years in Operation"
label variable experience_specific "Prior Experience in Same Type of Business"
label variable sector2 "Sector Dummy (1=manuf, 0=services (inc. retail))"
label variable dist_Inf_formal "Distance of Informal to Closest Formal Firm (Baseline)"
label variable dist_Inf_ES "Distance of Informal to Closest ES Firm"
label variable dist_Inf_formal_all_weak "Distance of Informal to Closest Formal Firm (Enumerated)"
label var ln_d2_l1 "Formal Labor Productivity (log)"


********************************************************************************
** Table 1: Digital Variables by Survey Type (in %) ****************************
********************************************************************************

svyset stratificationregioncode [pweight=wweak], strata(strata)
svy: mean c42a if type=="Inf"
svy: mean c42a if type=="Micro"
svy: mean c42b if type=="Inf"
svy: mean c42b if type=="Micro"
svy: mean c42c if type=="Inf"
svy: mean c42c if type=="Micro"
svy: mean ZAMc1 if type=="Inf"
svy: mean ZAMc1 if type=="Micro"
** Result for ES firms: See line 49 & 50.
svy: mean k11a if type=="Inf"
svy: mean k11a if type=="Micro"


********************************************************************************
** Table 2: Summary Statistics *************************************************
********************************************************************************

svyset stratificationregioncode [pweight=wweak], strata(strata)
svy: mean dist_Inf_formal 
svy: mean dist_Inf_ES 
svy: mean dist_Inf_formal_all_weak 
svy: mean dist_Inf_formal_web
svy: mean density_sq_infcount_weak 
svy: mean sc2 if type=="Inf"
svy: mean sc2 if type=="Micro"
svy: mean yr_op if type=="Inf"
svy: mean yr_op if type=="Micro"
svy: mean b9 if type=="Inf"
svy: mean b9 if type=="Micro"
svy: mean owner_a_high if type=="Inf"
svy: mean owner_a_high if type=="Micro"
svy: mean experience_specific if type=="Inf"
svy: mean experience_specific if type=="Micro"
svy: mean sector2 if type=="Inf"
svy: mean sector2 if type=="Micro"
svy: mean ln_d2_l1 if type=="Inf"
svy: mean lnlab2 if type=="Inf"
svy: mean gps_square__Altitude if type=="Inf"
svy: mean rastervalu if type=="Inf"


********************************************************************************
***** Table 3: Baseline Model **************************************************
********************************************************************************

local yvariable c42a c42b c42c k11a ZAMc1
local distvar dist_Inf_formal
local selcon1 sc2 yr_op b9 owner_a_high experience_specific sector2

forvalues v = 1/1 {
foreach yvar in `yvariable'{
logit `yvar' `distvar' `selcon`v'' i.city [pw=wweak], cluster(city) robust
eststo
matrix N_g = e(N_g)
local groups = N_g[1,1]
estadd local groups `groups'
local noobs = `e(N)'
local lbl: variable label `yvar'
quietly outreg2 using "$path\\Tables\Table 3.xls" , dec(3) ///
 ctitle(`yvar', `lbl') drop(i.city) ///
 addstat("Number of observations",`noobs') ///
 addnote("Notes: Standard errors are clustered at the city level. *** p<0.01, ** p<0.05, * p<0.1.") ///
 sortvar(`distvar' `selcon`v'' ) ///
 nocons noni noobs label excel 
}
}
 
eststo clear


********************************************************************************
***** Table 4: Baseline Model with Labor Productivity **************************
***** Appendix Tables A.2 ******************************************************
********************************************************************************

// Note: this code generates the full tables in the appendix. Table 4 was created manually.

local yvariable c42a c42b c42c k11a ZAMc1
local distvar dist_Inf_formal
local selcon3 sc2 yr_op b9 owner_a_high experience_specific sector2 lnlab2
local selcon4 sc2 yr_op b9 owner_a_high experience_specific sector2 ln_d2_l1
local selcon5 sc2 yr_op b9 owner_a_high experience_specific sector2 ln_d2_l1 lnlab2


forvalues v = 3/5 {
foreach yvar in `yvariable'{
logit `yvar' `distvar' `selcon`v'' i.city [pw=wweak], cluster(city) robust
eststo
matrix N_g = e(N_g)
local groups = N_g[1,1]
estadd local groups `groups'
local noobs = `e(N)'
local lbl: variable label `yvar'
quietly outreg2 using "$path\\Tables\Table 4 - Appendix Tables A2.xls" , dec(3) ///
 ctitle(`yvar', `lbl') drop(i.city) ///
 addstat("Number of observations",`noobs') ///
 addnote("Notes: Standard errors are clustered at the city level. *** p<0.01, ** p<0.05, * p<0.1.") ///
 sortvar(`distvar' `selcon`v'' ) ///
 nocons noni noobs label excel 
}
}
 
eststo clear


********************************************************************************
***** Table 5: Baseline Model with Additional Controls *************************
***** Appendix Tables A.3 ******************************************************
********************************************************************************

local yvariable c42a c42b c42c k11a ZAMc1
local distvar dist_Inf_formal
local selcon6 sc2 yr_op b9 owner_a_high experience_specific sector2 gps_square__Altitude
local selcon7 sc2 yr_op b9 owner_a_high experience_specific sector2 rastervalu

forvalues v = 6/7 {
foreach yvar in `yvariable'{
logit `yvar' `distvar' `selcon`v'' i.city [pw=wweak], cluster(city) robust
eststo
matrix N_g = e(N_g)
local groups = N_g[1,1]
estadd local groups `groups'
local noobs = `e(N)'
local lbl: variable label `yvar'
quietly outreg2 using "$path\\Tables\Table 5 - Appendix Tables A3.xls" , dec(3) ///
 ctitle(`yvar', `lbl') drop(i.city) ///
 addstat("Number of observations",`noobs') ///
 addnote("Notes: Standard errors are clustered at the city level. *** p<0.01, ** p<0.05, * p<0.1.") ///
 sortvar(`distvar' `selcon`v'' ) ///
 nocons noni noobs label excel 
}
}
 
eststo clear


********************************************************************************
***** Table 6: Summary of Type of Premises: Informal Businesses ****************
********************************************************************************

tab c1a


********************************************************************************
***** Table 7: Effects of Distance for the Permanent Location Sample ***********
********************************************************************************

gen location=.
replace location=1 if c1a==1
replace location=2 if c1a==2
replace location=3 if c1a==3|c1a==4

gen perm=.
replace perm=1 if location==1|location==2
replace perm=0 if location==3
label variable perm "Permanent Location"

local yvariable c42a c42b c42c k11a ZAMc1
local distvar dist_Inf_formal
local selcon1 sc2 yr_op b9 owner_a_high experience_specific sector2

forvalues v = 1/1 {
foreach yvar in `yvariable'{
logit `yvar' `distvar' `selcon`v'' i.city [pw=wweak] if perm==1, cluster(city) robust
eststo
matrix N_g = e(N_g)
local groups = N_g[1,1]
estadd local groups `groups'
local noobs = `e(N)'
local lbl: variable label `yvar'
quietly outreg2 using "$path\\Tables\Table 7.xls" , dec(3) ///
 ctitle(`yvar', `lbl')  drop(i.city) ///
 addstat("Number of observations",`noobs') ///
 addnote("Notes: Standard errors are clustered at the city level. *** p<0.01, ** p<0.05, * p<0.1.") ///
 sortvar(`distvar' `selcon`v'' ) ///
 nocons noni noobs label excel 
}
}
 
eststo clear


********************************************************************************
***** Table 8: Alternative Distance Measures ***********************************
***** Appendix Tables A.4 and A.5 **********************************************
********************************************************************************

local yvariable c42a c42b c42c k11a ZAMc1
local distvariable dist_Inf_formal dist_Inf_ES dist_Inf_formal_all_weak dist_Inf_formal_web
local selcon1 sc2 yr_op b9 owner_a_high experience_specific sector2

foreach distvar in `distvariable'{
forvalues v = 1/1 {
foreach yvar in `yvariable'{
logit `yvar' `distvar' `selcon`v'' i.city [pw=wweak], cluster(city) robust
eststo
matrix N_g = e(N_g)
local groups = N_g[1,1]
estadd local groups `groups'
local noobs = `e(N)'
local lbl: variable label `yvar'
quietly outreg2 using "$path\\Tables\Table 8 - Appendix Tables A4_A5.xls" , dec(3) ///
 ctitle(`yvar', `lbl') drop(i.city) ///
 addstat("Number of observations",`noobs') ///
 addnote("Notes: Standard errors are clustered at the city level. *** p<0.01, ** p<0.05, * p<0.1.") ///
 sortvar(`selcon`v'' `distvar') ///
 nocons noni noobs label excel 
}
}
}
 
eststo clear



********************************************************************************
***** Figure 2: Heterogenous Effects by Owner's Level of Education *************
***** Appendix Table A.6: Heterogenous Effects: Owner's Level of Education *****
********************************************************************************

** Figure 2
local yvariable c42a c42b c42c k11a ZAMc1
local distvar dist_Inf_formal
local selcon1 sc2 yr_op b9 experience_specific sector2 i.city
local source1 owner_a_high

set scheme s2color
foreach yvar in `yvariable'{
logit `yvar' c.`distvar'##c.`source1' `selcon1' [pw=wweak], cluster(city) robust
margins, dydx(`distvar') at (`source1'=(0(1)1))
marginsplot, recast(dot) plotopts(dcolor(white%0)) ytitle("Effect on `: var label `yvar''", size(medlarge)) xtitle("Owner's Education is above Secondary School", size(medium)) ///
			 title("") level(95)  xlabel(0 "No" 1 "Yes") ///
             ylabel(, format(%9.2f)) xlabel(,labsize(medium)) graphregion(margin(l+1 r+1) fcolor(white)) legend(off)  yline(0, lwidth(0.5pt) lcolor(red)) xscale(r(-0.25 1.25)) 
graph save Figure_`yvar'_OwnerEduc.gph, replace
}

graph combine Figure_c42a_OwnerEduc.gph Figure_c42b_OwnerEduc.gph Figure_c42c_OwnerEduc.gph Figure_k11a_OwnerEduc.gph, cols(2) ysize(4) iscale(.6) graphregion(fcolor(white))
graph export "$path\\Figures\Figure 2.pdf", replace


*** Appendix Table A.6
local yvariable c42a c42b c42c k11a ZAMc1
local distvar dist_Inf_formal
local selcon1 sc2 yr_op b9 experience_specific sector2 i.city
local source1 owner_a_high

forvalues v = 1/1 {
foreach yvar in `yvariable'{
logit `yvar' c.`distvar'##c.`source1' `selcon`v'' [pw=wweak], cluster(city) robust
eststo
matrix N_g = e(N_g)
local groups = N_g[1,1]
estadd local groups `groups'
local noobs = `e(N)'
local lbl: variable label `yvar'
quietly outreg2 using "$path\\Tables\Appendix Table A6.xls" , dec(3) ///
 ctitle(`yvar', `lbl') drop(i.city) ///
 addstat("Number of Observations",`noobs') ///
 addnote("Notes: Standard errors are clustered at the city level. *** p<0.01, ** p<0.05, * p<0.1.") ///
 sortvar(`distvar' `source1') ///
 nocons noni noobs label excel 
}
}

eststo clear


********************************************************************************
***** Figure 3: Heterogenous Effects by Business Age ***************************
***** Appendix Table A.7: Heterogenous Effects: Business Age *******************
***** Appendix Figure A.1: Histogram of the Start of the Business Activity ****
********************************************************************************

gen old=. if b3!=.
replace old=1 if b3!=.&b3<=2015
replace old=0 if b3!=.&b3>2015
label variable old "Business Age (<2016)"

generate start=b3 
replace start=2019 if start==2020 // To create a better looking histogram
label variable start "Start Year of Business or Activity"


*** Figure 3

local yvariable c42a c42b c42c k11a ZAMc1
local distvar dist_Inf_formal
local selcon1 sc2 b9 owner_a_high experience_specific sector2 i.city 
local source1 old

set scheme s2color
foreach yvar in `yvariable'{
logit `yvar' c.`distvar'##c.`source1' `selcon1' [pw=wweak], cluster(city) robust
margins, dydx(`distvar') at (`source1'=(0(1)1))
marginsplot, recast(dot) plotopts(dcolor(white%0)) ytitle("Effect on `: var label `yvar''", size(medlarge)) xtitle("Business Existed before 2016", size(medium)) ///
			 title("") level(95)  xlabel(0 "No" 1 "Yes") ///
             ylabel(, format(%9.2f)) xlabel(,labsize(medium)) graphregion(margin(l+1 r+1) fcolor(white)) legend(off)  yline(0, lwidth(0.5pt) lcolor(red)) xscale(r(-0.25 1.25)) 
graph save Figure_`yvar'_Het4.gph, replace
}

graph combine Figure_c42a_Het4.gph Figure_c42b_Het4.gph Figure_c42c_Het4.gph Figure_k11a_Het4.gph, cols(2) ysize(4) iscale(.6) graphregion(fcolor(white))
graph export "$path\\Figures\Figure 3.pdf", replace


*** Appendix Table A.7

local yvariable c42a c42b c42c k11a ZAMc1
local distvar dist_Inf_formal
local selcon1 sc2 b9 owner_a_high experience_specific sector2 i.city 
local source1 old

forvalues v = 1/1 {
foreach yvar in `yvariable'{
logit `yvar' c.`distvar'##c.`source1' `selcon`v'' [pw=wweak], cluster(city) robust
eststo
matrix N_g = e(N_g)
local groups = N_g[1,1]
estadd local groups `groups'
local noobs = `e(N)'
local lbl: variable label `yvar'
quietly outreg2 using "$path\\Tables\Appendix Table A7.xls" , dec(3) ///
 ctitle(`yvar', `lbl') drop(i.city) ///
 addstat("Number of Observations",`noobs') ///
 addnote("Notes: Standard errors are clustered at the city level. *** p<0.01, ** p<0.05, * p<0.1.") ///
 sortvar(`distvar' `source1') ///
 nocons noni noobs label excel 
}
}

eststo clear

** Appendix Figure A.1
hist start, graphregion(fcolor(white)) percent
graph save Figure_FirmAgeAll.gph, replace 
hist start if start>2009, graphregion(fcolor(white)) percent
graph save Figure_FirmAge2010.gph, replace
graph combine Figure_FirmAgeAll.gph Figure_FirmAge2010.gph, cols(2) ysize(2) iscale(1.3) graphregion(fcolor(white))
graph export "$path\\Figures\Appendix Figure A1.pdf" , replace



********************************************************************************
***** Table 9: Effect of Number of Informal Businesses within a Square *********
********************************************************************************

local yvariable c42a c42b c42c k11a ZAMc1 
local distvariable density_sq_infcount_weak
local selcon1 sc2 yr_op b9 owner_a_high experience_specific sector2

foreach distvar in `distvariable'{ 
forvalues v = 1/1 {
foreach yvar in `yvariable'{
logit `yvar' `distvar' `selcon`v'' i.city [pw=wweak], cluster(city) robust
eststo
matrix N_g = e(N_g)
local groups = N_g[1,1]
estadd local groups `groups'
local noobs = `e(N)'
local lbl: variable label `yvar'
quietly outreg2 using "$path\\Tables\Table 9.xls", dec(3) ///
 ctitle(`yvar', `lbl') drop(i.city) ///
 addstat("Number of observations",`noobs') ///
 addnote("Notes: Standard errors are clustered at the city level. *** p<0.01, ** p<0.05, * p<0.1.") ///
 sortvar(`distvar' `selcon`v'' ) ///
 nocons noni noobs label excel 
}
}
}
 
eststo clear


********************************************************************************
***** Figure 4: Interaction with Visiting Competitors **************************
***** Appendix Table A.8: Interaction with Visiting Competitors ****************
********************************************************************************

*** Figure 4
local yvariable c42a c42b c42c k11a ZAMc1
local distvar dist_Inf_formal
local selcon1 sc2 yr_op b9 owner_a_high experience_specific sector2 i.city
local source1 d_ir1a

set scheme s2color
foreach yvar in `yvariable'{
logit `yvar' c.`distvar'##c.`source1' `selcon1' [pw=wweak], cluster(city) robust
margins, dydx(`distvar') at (`source1'=(0(1)1))
marginsplot, recast(dot) plotopts(dcolor(white%0)) ytitle("Effect on `: var label `yvar''", size(medlarge)) xtitle("Visited Competitors", size(medium)) ///
			 title("") level(95)  xlabel(0 "No" 1 "Yes") ///
             ylabel(, format(%9.2f)) xlabel(,labsize(medium)) graphregion(margin(l+1 r+1) fcolor(white)) legend(off)  yline(0, lwidth(0.5pt) lcolor(red)) xscale(r(-0.25 1.25)) 
graph save Figure_`yvar'_Het6.gph, replace
}

graph combine Figure_c42a_Het6.gph Figure_c42b_Het6.gph Figure_c42c_Het6.gph Figure_k11a_Het6.gph Figure_ZAMc1_Het6.gph, cols(2) ysize(6) iscale(.5) graphregion(fcolor(white))
graph export "$path\\Figures\Figure 4.pdf", replace


*** Appendix Table A.8
local yvariable c42a c42b c42c k11a ZAMc1
local distvar dist_Inf_formal
local selcon1 sc2 yr_op b9 owner_a_high experience_specific sector2 i.city
local source1 d_ir1a

forvalues u= 1/1{
forvalues v = 1/1 {
foreach yvar in `yvariable'{
logit `yvar' c.`distvar'##c.`source`u'' `selcon`v'' [pw=wweak], cluster(city) robust
eststo
matrix N_g = e(N_g)
local groups = N_g[1,1]
estadd local groups `groups'
local noobs = `e(N)'
local lbl: variable label `yvar'
quietly outreg2 using "$path\\Tables\Appendix Table A8.xls" , dec(3) ///
 ctitle(`yvar', `lbl') drop(i.city) ///
 addstat("Number of observations",`noobs') ///
 addnote("Notes: Standard errors are clustered at the city level. *** p<0.01, ** p<0.05, * p<0.1.") ///
 sortvar(`distvar' `source`u'') ///
 nocons noni noobs label excel 
}
}
}

eststo clear


********************************************************************************
***** Table 10: Value-Chain Linkages by Survey Type (in %) *********************
********************************************************************************

svyset stratificationregioncode [pweight=wweak], strata(strata)
svy: tab ZAMd1 if type=="Inf"
svy: tab ZAMd1 if type=="Micro"
svy: tab ZAMd2 if type=="Inf"
svy: tab ZAMd2 if type=="Micro"



********************************************************************************
***** Figure 5: Heterogenous Effects of Distance by Type of Input Source *******
***** Appendix Table A.9: Heterogenous Effects of Distance by Type of Input Source
********************************************************************************

generate source_large=0 if ZAMd2==1 | ZAMd2==2 | ZAMd2==4 | ZAMd2==5
replace source_large=1 if ZAMd2==3

generate source_business=0 if ZAMd2==1 | ZAMd2==4 | ZAMd2==5
replace source_business=1 if ZAMd2==3 | ZAMd2==2

label variable source_large "Input from Large Business"
label variable source_business "Input from a Business"


*** Figure 5

local yvariable c42a c42b c42c k11a ZAMc1
local distvar dist_Inf_formal
local selcon1 sc2 yr_op b9 owner_a_high experience_specific sector2 i.city
local source1 source_business

set scheme s2color
foreach yvar in `yvariable'{
logit `yvar' c.`distvar'##c.`source1' `selcon1' [pw=wweak], cluster(city) robust
margins, dydx(`distvar') at (`source1'=(0(1)1))
marginsplot, recast(dot) plotopts(dcolor(white%0)) ytitle("Effect on `: var label `yvar''", size(medlarge)) xtitle("Main Source of Inputs from a Business", size(medium)) ///
			 title("") level(95)  xlabel(0 "No" 1 "Yes") ///
             ylabel(, format(%9.2f)) xlabel(,labsize(medium)) graphregion(margin(l+1 r+1) fcolor(white)) legend(off)  yline(0, lwidth(0.5pt) lcolor(red)) xscale(r(-0.25 1.25)) 
graph save Figure_`yvar'_Het5.gph, replace
}

graph combine Figure_c42a_Het5.gph Figure_c42b_Het5.gph Figure_c42c_Het5.gph Figure_k11a_Het5.gph, cols(2) ysize(4) iscale(.6) graphregion(fcolor(white))
graph export "$path\\Figures\Figure 5.pdf", replace



*** Appendix Table A.9
local yvariable c42a c42b c42c k11a ZAMc1
local distvar dist_Inf_formal
local selcon1 sc2 yr_op b9 owner_a_high experience_specific sector2 i.city
local source1 source_business

forvalues u= 1/1{
forvalues v = 1/1 {
foreach yvar in `yvariable'{
logit `yvar' c.`distvar'##c.`source`u'' `selcon`v'' [pw=wweak], cluster(city) robust
eststo
matrix N_g = e(N_g)
local groups = N_g[1,1]
estadd local groups `groups'
local noobs = `e(N)'
local lbl: variable label `yvar'
quietly outreg2 using "$path\\Tables\Appendix Table A9.xls" , dec(3) ///
 ctitle(`yvar', `lbl') drop(i.city) ///
 addstat("Number of observations",`noobs') ///
 addnote("Notes: Standard errors are clustered at the city level. *** p<0.01, ** p<0.05, * p<0.1.") ///
 sortvar(`distvar' `source`u'') ///
 nocons noni noobs label excel 
}
}
}

eststo clear


********************************************************************************
** Appendix Table A.1: Firm Registration Status by Survey Types ****************
********************************************************************************

bys type: tab sc3a
bys type: tab sc3b
bys type: tab sc3c

** Note that the numbers for ES are by construction. 

********************************************************************************
** Appendix Table A.3.3: Alternative Fixed Effects *****************************
********************************************************************************

** Divide city by quadrants and create new measure
tostring id_square, gen(ids_str)
gen row = substr(ids_str,2,5)
gen col = substr(ids_str,6,9)
destring row col, replace

bys city: su row col

gen nw = 1 if inrange(col,1,71) & inrange(row,30,755) & city == 1
gen ne = 1 if inrange(col,72,142) & inrange(row,30,755) & city == 1
gen sw = 1 if inrange(col,1,71) & inrange(row,756,1480) & city == 1
gen se = 1 if inrange(col,72,142) & inrange(row,756,1480) & city == 1

replace nw = 1 if inrange(col,16,48) & inrange(row,10,660) & city == 2
replace ne = 1 if inrange(col,49,80) & inrange(row,10,660) & city == 2
replace sw = 1 if inrange(col,16,48) & inrange(row,661,1310) & city == 2
replace se = 1 if inrange(col,49,80) & inrange(row,661,1310) & city == 2

replace nw = 1 if inrange(col,1,51) & inrange(row,120,620) & city == 3
replace ne = 1 if inrange(col,52,102) & inrange(row,120,620) & city == 3
replace sw = 1 if inrange(col,1,51) & inrange(row,621,1120) & city == 3
replace se = 1 if inrange(col,52,102) & inrange(row,621,1120) & city == 3

gen part = .
replace part = 1 if nw==1
replace part = 2 if ne==1
replace part = 3 if sw==1
replace part = 4 if se==1

egen city_part = group(city part)


** Estimation
local yvariable c42a c42b c42c k11a ZAMc1
local distvar dist_Inf_formal
local selcon1 sc2 yr_op b9 owner_a_high experience_specific sector2

forvalues v = 1/1 {
foreach yvar in `yvariable'{
logit `yvar' `distvar' `selcon`v'' i.city_part [pw=wweak], cluster(city_part) robust
eststo
matrix N_g = e(N_g)
local groups = N_g[1,1]
estadd local groups `groups'
local noobs = `e(N)'
local lbl: variable label `yvar'
quietly outreg2 using "$path\\Tables\Appendix Table A3-3.xls" , dec(3) ///
 ctitle(`yvar', `lbl', Quadrant FE) drop(i.city_part) ///
 addstat("Number of observations",`noobs') ///
 addnote("Notes: Standard errors are clustered at the cluster level. *** p<0.01, ** p<0.05, * p<0.1.") ///
 sortvar(`distvar' `selcon`v'' ) ///
 nocons noni noobs label excel 
}
}

eststo clear


********************************************************************************
** Appendix Table B.1: Density Model *******************************************
********************************************************************************

local yvariable c42a c42b c42c k11a ZAMc1
local distvariable density_sq_fcount_weak
local selcon1 sc2 yr_op b9 owner_a_high experience_specific sector2

foreach distvar in `distvariable'{ 
forvalues v = 1/1 {
foreach yvar in `yvariable'{
logit `yvar' `distvar' `selcon`v'' i.city [pw=wweak], cluster(city) robust
eststo
matrix N_g = e(N_g)
local groups = N_g[1,1]
estadd local groups `groups'
local noobs = `e(N)'
local lbl: variable label `yvar'
quietly outreg2 using "$path\\Tables\Appendix Table B1.xls" , dec(3) ///
 ctitle(`yvar', `lbl') drop(i.city) ///
 addstat("Number of observations",`noobs') ///
 addnote("Notes: Standard errors are clustered at the city level. *** p<0.01, ** p<0.05, * p<0.1.") ///
 sortvar(`distvar' `selcon`v'' ) ///
 nocons noni noobs label excel 
}
}
}
 
eststo clear
